<div class="glide" id="{{ carousel_id }}">
  <div class="glide__track" data-glide-el="track">
    <ul class="glide__slides">
      {% for item in items %}
        {% include slide_template with item=item only %}
      {% endfor %}
    </ul>
  </div>
</div>

<script>
  document.addEventListener("DOMContentLoaded", function () {
    new Glide('#{{ carousel_id }}', {{ options|safe|default:"{}" }}).mount();
  });
</script>
